pub struct FrameDecoder<R: Read> { /* private fields */ }Expand description
Streaming zstd decompressor implementing Read.
Wraps a reader of compressed data and yields decompressed bytes. Supports multi-frame streams and skippable frames.
use std::io::Read;
let data = b"hello, streaming world!".repeat(100);
let compressed = zrip::compress(&data, 1).unwrap();
let mut decoder = zrip::FrameDecoder::new(&compressed[..]);
let mut output = Vec::new();
decoder.read_to_end(&mut output).unwrap();
assert_eq!(output, data);Implementations
Sourceimpl<R: Read> FrameDecoder<R>
impl<R: Read> FrameDecoder<R>
Sourcepub fn new(reader: R) -> Self
pub fn new(reader: R) -> Self
Creates a decoder with DEFAULT_DECOMPRESS_LIMIT.
Sourcepub fn with_limit(reader: R, max_output: usize) -> Self
pub fn with_limit(reader: R, max_output: usize) -> Self
Creates a decoder with an explicit output size limit.
Sourcepub fn with_dict(reader: R, dict: Dictionary) -> Self
pub fn with_dict(reader: R, dict: Dictionary) -> Self
Creates a decoder with a dictionary and default output limit.
Sourcepub fn with_dict_and_limit(
reader: R,
dict: Dictionary,
max_output: usize,
) -> Self
pub fn with_dict_and_limit( reader: R, dict: Dictionary, max_output: usize, ) -> Self
Creates a decoder with a dictionary and explicit output limit.
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Consumes the decoder and returns the underlying reader.